@@ -22,9 +22,11 @@
 
 #include "pa_utils.h"
 
+#include <QLineEdit>
 #include <QSettings>
 #include <QString>
-#include <QLineEdit>
+#include <QTime>
+#include <QTextStream>
 
 #include "analogmeterwidget.h"
 #include "horizontalvolumebarwidget.h"
@@ -35,6 +37,8 @@ MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
 {
+    logFile = NULL;
+    logIndex = 0;
     process = NULL;
     triggerCount = 0;
     volumeMeterWidget = NULL;
@@ -110,6 +114,54 @@ MainWindow::~MainWindow()
 
     delete volumeMeterWidget;
     pa_shutdown();
+
+    closeFile(logFile);
+}
+
+void MainWindow::applySettings(){
+    QSettings settings;
+    triggerValue = settings.value(SettingsDialog::TRIGGER_VALUE, 0).toInt();
+    triggerCommand = settings.value(SettingsDialog::TRIGGER_COMMAND, "").toString();
+    triggerCountSetting = settings.value(SettingsDialog::TRIGGER_COUNT, 0).toInt();
+
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5AutoOrientation,
+                 settings.value(SettingsDialog::AUTO_ROTATE, false).toBool());
+#endif
+
+    volumeMeterWidget->setTriggerValue(triggerValue);
+    volumeMeterWidget->setUseColoredScale(settings.value(SettingsDialog::COLOR_SCALE, false).toBool());
+    volumeMeterWidget->setColors(settings.value(SettingsDialog::COLOR_LOWER_COLOR, QColor(Qt::green)).value<QColor>(),
+                                 settings.value(SettingsDialog::COLOR_MID_COLOR, QColor(Qt::yellow)).value<QColor>(),
+                                 settings.value(SettingsDialog::COLOR_UPPER_COLOR, QColor(Qt::red)).value<QColor>());
+    volumeMeterWidget->setColorThresholds(settings.value(SettingsDialog::COLOR_LOWER_THRESHOLD, 60).toInt(),
+                                          settings.value(SettingsDialog::COLOR_UPPER_THRESHOLD, 95).toInt());
+
+    loggingEnabled = settings.value(SettingsDialog::LOG_LOGGING_ENABLED, false).toBool();
+    logFileName = settings.value(SettingsDialog::LOG_FILE_NAME, tr("Select File")).toString();
+
+    if(loggingEnabled){
+        if(logFile != NULL && logFile->fileName().compare(logFileName) != 0){
+            closeFile(logFile);
+        }
+
+        if(logFile == NULL){
+            logIndex = 0;
+            logFile = new QFile(logFileName);
+            logFile->open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text);
+        }
+    }
+}
+
+void MainWindow::closeFile(QFile *file){
+    if(file != NULL && file->isOpen()){
+        qDebug("Closing file %s.", file->fileName().toLocal8Bit().data());
+        file->flush();
+        file->close();
+        delete file;
+        file = NULL;
+        qDebug("File closed.");
+    }
 }
 
 void MainWindow::changeMeter(){
@@ -136,26 +188,6 @@ void MainWindow::changeMeter(){
     connect(volumeMeterWidget, SIGNAL(clicked()), this, SLOT(changeMeter()));
 }
 
-void MainWindow::applySettings(){
-    QSettings settings;
-    triggerValue = settings.value(SettingsDialog::TRIGGER_VALUE, 0).toInt();
-    triggerCommand = settings.value(SettingsDialog::TRIGGER_COMMAND, "").toString();
-    triggerCountSetting = settings.value(SettingsDialog::TRIGGER_COUNT, 0).toInt();
-
-#ifdef Q_WS_MAEMO_5
-    setAttribute(Qt::WA_Maemo5AutoOrientation,
-                 settings.value(SettingsDialog::AUTO_ROTATE, false).toBool());
-#endif
-
-    volumeMeterWidget->setTriggerValue(triggerValue);
-    volumeMeterWidget->setUseColoredScale(settings.value(SettingsDialog::COLOR_SCALE, false).toBool());
-    volumeMeterWidget->setColors(settings.value(SettingsDialog::COLOR_LOWER_COLOR, QColor(Qt::green)).value<QColor>(),
-                                 settings.value(SettingsDialog::COLOR_MID_COLOR, QColor(Qt::yellow)).value<QColor>(),
-                                 settings.value(SettingsDialog::COLOR_UPPER_COLOR, QColor(Qt::red)).value<QColor>());
-    volumeMeterWidget->setColorThresholds(settings.value(SettingsDialog::COLOR_LOWER_THRESHOLD, 60).toInt(),
-                                          settings.value(SettingsDialog::COLOR_UPPER_THRESHOLD, 95).toInt());
-}
-
 void MainWindow::processFinished(){
     if(process != NULL){
         process->deleteLater();
@@ -224,6 +256,15 @@ void MainWindow::updateValues(float value){
         vol = 0;
     }
 
+    if(loggingEnabled){
+        QTextStream out(logFile);
+        out << logIndex << ";"
+                << QTime::currentTime().toString("hh:mm:ss.zzz") << ";"
+                << vol << ";"
+                << ((ui->radioButtonDb->isChecked()) ? "dB" : "Linear") << "\n";
+        logIndex++;
+    }
+
     if(vol > triggerValue && process == NULL){
         if(triggerCount >= triggerCountSetting){
             process = new QProcess();
