@@ -109,6 +109,17 @@ void VolumeMeterWidget::resizeEvent(QResizeEvent */*event*/){
     }
 }
 
+void VolumeMeterWidget::setColors(QColor lower, QColor mid, QColor upper){
+    lowerColor = lower;
+    midColor = mid;
+    upperColor = upper;
+}
+
+void VolumeMeterWidget::setColorThresholds(int lower, int upper){
+    lowerThreshold = lower;
+    upperThreshold = upper;
+}
+
 void VolumeMeterWidget::setDbUnit(bool b){
     dbUnit = b;
     currentValue = 0;
